package v1
import "github.com/sigstore/protobuf-specs/gen/pb-go/common/v1"
Index ¶
- Variables
- type DistinguishedName
- func (*DistinguishedName) Descriptor() ([]byte, []int)
- func (x *DistinguishedName) GetCommonName() string
- func (x *DistinguishedName) GetOrganization() string
- func (*DistinguishedName) ProtoMessage()
- func (x *DistinguishedName) ProtoReflect() protoreflect.Message
- func (x *DistinguishedName) Reset()
- func (x *DistinguishedName) String() string
- type HashAlgorithm
- func (HashAlgorithm) Descriptor() protoreflect.EnumDescriptor
- func (x HashAlgorithm) Enum() *HashAlgorithm
- func (HashAlgorithm) EnumDescriptor() ([]byte, []int)
- func (x HashAlgorithm) Number() protoreflect.EnumNumber
- func (x HashAlgorithm) String() string
- func (HashAlgorithm) Type() protoreflect.EnumType
- type HashOutput
- func (*HashOutput) Descriptor() ([]byte, []int)
- func (x *HashOutput) GetAlgorithm() HashAlgorithm
- func (x *HashOutput) GetDigest() []byte
- func (*HashOutput) ProtoMessage()
- func (x *HashOutput) ProtoReflect() protoreflect.Message
- func (x *HashOutput) Reset()
- func (x *HashOutput) String() string
- type LogId
- func (*LogId) Descriptor() ([]byte, []int)
- func (x *LogId) GetKeyId() []byte
- func (*LogId) ProtoMessage()
- func (x *LogId) ProtoReflect() protoreflect.Message
- func (x *LogId) Reset()
- func (x *LogId) String() string
- type MessageSignature
- func (*MessageSignature) Descriptor() ([]byte, []int)
- func (x *MessageSignature) GetMessageDigest() *HashOutput
- func (x *MessageSignature) GetSignature() []byte
- func (*MessageSignature) ProtoMessage()
- func (x *MessageSignature) ProtoReflect() protoreflect.Message
- func (x *MessageSignature) Reset()
- func (x *MessageSignature) String() string
- type ObjectIdentifier
- func (*ObjectIdentifier) Descriptor() ([]byte, []int)
- func (x *ObjectIdentifier) GetId() []int32
- func (*ObjectIdentifier) ProtoMessage()
- func (x *ObjectIdentifier) ProtoReflect() protoreflect.Message
- func (x *ObjectIdentifier) Reset()
- func (x *ObjectIdentifier) String() string
- type ObjectIdentifierValuePair
- func (*ObjectIdentifierValuePair) Descriptor() ([]byte, []int)
- func (x *ObjectIdentifierValuePair) GetOid() *ObjectIdentifier
- func (x *ObjectIdentifierValuePair) GetValue() []byte
- func (*ObjectIdentifierValuePair) ProtoMessage()
- func (x *ObjectIdentifierValuePair) ProtoReflect() protoreflect.Message
- func (x *ObjectIdentifierValuePair) Reset()
- func (x *ObjectIdentifierValuePair) String() string
- type PublicKey
- func (*PublicKey) Descriptor() ([]byte, []int)
- func (x *PublicKey) GetKeyDetails() PublicKeyDetails
- func (x *PublicKey) GetRawBytes() []byte
- func (x *PublicKey) GetValidFor() *TimeRange
- func (*PublicKey) ProtoMessage()
- func (x *PublicKey) ProtoReflect() protoreflect.Message
- func (x *PublicKey) Reset()
- func (x *PublicKey) String() string
- type PublicKeyDetails
- func (PublicKeyDetails) Descriptor() protoreflect.EnumDescriptor
- func (x PublicKeyDetails) Enum() *PublicKeyDetails
- func (PublicKeyDetails) EnumDescriptor() ([]byte, []int)
- func (x PublicKeyDetails) Number() protoreflect.EnumNumber
- func (x PublicKeyDetails) String() string
- func (PublicKeyDetails) Type() protoreflect.EnumType
- type PublicKeyIdentifier
- func (*PublicKeyIdentifier) Descriptor() ([]byte, []int)
- func (x *PublicKeyIdentifier) GetHint() string
- func (*PublicKeyIdentifier) ProtoMessage()
- func (x *PublicKeyIdentifier) ProtoReflect() protoreflect.Message
- func (x *PublicKeyIdentifier) Reset()
- func (x *PublicKeyIdentifier) String() string
- type RFC3161SignedTimestamp
- func (*RFC3161SignedTimestamp) Descriptor() ([]byte, []int)
- func (x *RFC3161SignedTimestamp) GetSignedTimestamp() []byte
- func (*RFC3161SignedTimestamp) ProtoMessage()
- func (x *RFC3161SignedTimestamp) ProtoReflect() protoreflect.Message
- func (x *RFC3161SignedTimestamp) Reset()
- func (x *RFC3161SignedTimestamp) String() string
- type SubjectAlternativeName
- func (*SubjectAlternativeName) Descriptor() ([]byte, []int)
- func (x *SubjectAlternativeName) GetIdentity() isSubjectAlternativeName_Identity
- func (x *SubjectAlternativeName) GetRegexp() string
- func (x *SubjectAlternativeName) GetType() SubjectAlternativeNameType
- func (x *SubjectAlternativeName) GetValue() string
- func (*SubjectAlternativeName) ProtoMessage()
- func (x *SubjectAlternativeName) ProtoReflect() protoreflect.Message
- func (x *SubjectAlternativeName) Reset()
- func (x *SubjectAlternativeName) String() string
- type SubjectAlternativeNameType
- func (SubjectAlternativeNameType) Descriptor() protoreflect.EnumDescriptor
- func (x SubjectAlternativeNameType) Enum() *SubjectAlternativeNameType
- func (SubjectAlternativeNameType) EnumDescriptor() ([]byte, []int)
- func (x SubjectAlternativeNameType) Number() protoreflect.EnumNumber
- func (x SubjectAlternativeNameType) String() string
- func (SubjectAlternativeNameType) Type() protoreflect.EnumType
- type SubjectAlternativeName_Regexp
- type SubjectAlternativeName_Value
- type TimeRange
- func (*TimeRange) Descriptor() ([]byte, []int)
- func (x *TimeRange) GetEnd() *timestamppb.Timestamp
- func (x *TimeRange) GetStart() *timestamppb.Timestamp
- func (*TimeRange) ProtoMessage()
- func (x *TimeRange) ProtoReflect() protoreflect.Message
- func (x *TimeRange) Reset()
- func (x *TimeRange) String() string
- type X509Certificate
- func (*X509Certificate) Descriptor() ([]byte, []int)
- func (x *X509Certificate) GetRawBytes() []byte
- func (*X509Certificate) ProtoMessage()
- func (x *X509Certificate) ProtoReflect() protoreflect.Message
- func (x *X509Certificate) Reset()
- func (x *X509Certificate) String() string
- type X509CertificateChain
- func (*X509CertificateChain) Descriptor() ([]byte, []int)
- func (x *X509CertificateChain) GetCertificates() []*X509Certificate
- func (*X509CertificateChain) ProtoMessage()
- func (x *X509CertificateChain) ProtoReflect() protoreflect.Message
- func (x *X509CertificateChain) Reset()
- func (x *X509CertificateChain) String() string
Variables ¶
var ( HashAlgorithm_name = map[int32]string{ 0: "HASH_ALGORITHM_UNSPECIFIED", 1: "SHA2_256", 2: "SHA2_384", 3: "SHA2_512", 4: "SHA3_256", 5: "SHA3_384", } HashAlgorithm_value = map[string]int32{ "HASH_ALGORITHM_UNSPECIFIED": 0, "SHA2_256": 1, "SHA2_384": 2, "SHA2_512": 3, "SHA3_256": 4, "SHA3_384": 5, } )
Enum value maps for HashAlgorithm.
var ( PublicKeyDetails_name = map[int32]string{ 0: "PUBLIC_KEY_DETAILS_UNSPECIFIED", 1: "PKCS1_RSA_PKCS1V5", 2: "PKCS1_RSA_PSS", 3: "PKIX_RSA_PKCS1V5", 4: "PKIX_RSA_PSS", 9: "PKIX_RSA_PKCS1V15_2048_SHA256", 10: "PKIX_RSA_PKCS1V15_3072_SHA256", 11: "PKIX_RSA_PKCS1V15_4096_SHA256", 16: "PKIX_RSA_PSS_2048_SHA256", 17: "PKIX_RSA_PSS_3072_SHA256", 18: "PKIX_RSA_PSS_4096_SHA256", 6: "PKIX_ECDSA_P256_HMAC_SHA_256", 5: "PKIX_ECDSA_P256_SHA_256", 12: "PKIX_ECDSA_P384_SHA_384", 13: "PKIX_ECDSA_P521_SHA_512", 7: "PKIX_ED25519", 8: "PKIX_ED25519_PH", 19: "PKIX_ECDSA_P384_SHA_256", 20: "PKIX_ECDSA_P521_SHA_256", 14: "LMS_SHA256", 15: "LMOTS_SHA256", 21: "ML_DSA_65", 22: "ML_DSA_87", } PublicKeyDetails_value = map[string]int32{ "PUBLIC_KEY_DETAILS_UNSPECIFIED": 0, "PKCS1_RSA_PKCS1V5": 1, "PKCS1_RSA_PSS": 2, "PKIX_RSA_PKCS1V5": 3, "PKIX_RSA_PSS": 4, "PKIX_RSA_PKCS1V15_2048_SHA256": 9, "PKIX_RSA_PKCS1V15_3072_SHA256": 10, "PKIX_RSA_PKCS1V15_4096_SHA256": 11, "PKIX_RSA_PSS_2048_SHA256": 16, "PKIX_RSA_PSS_3072_SHA256": 17, "PKIX_RSA_PSS_4096_SHA256": 18, "PKIX_ECDSA_P256_HMAC_SHA_256": 6, "PKIX_ECDSA_P256_SHA_256": 5, "PKIX_ECDSA_P384_SHA_384": 12, "PKIX_ECDSA_P521_SHA_512": 13, "PKIX_ED25519": 7, "PKIX_ED25519_PH": 8, "PKIX_ECDSA_P384_SHA_256": 19, "PKIX_ECDSA_P521_SHA_256": 20, "LMS_SHA256": 14, "LMOTS_SHA256": 15, "ML_DSA_65": 21, "ML_DSA_87": 22, } )
Enum value maps for PublicKeyDetails.
var ( SubjectAlternativeNameType_name = map[int32]string{ 0: "SUBJECT_ALTERNATIVE_NAME_TYPE_UNSPECIFIED", 1: "EMAIL", 2: "URI", 3: "OTHER_NAME", } SubjectAlternativeNameType_value = map[string]int32{ "SUBJECT_ALTERNATIVE_NAME_TYPE_UNSPECIFIED": 0, "EMAIL": 1, "URI": 2, "OTHER_NAME": 3, } )
Enum value maps for SubjectAlternativeNameType.
var File_sigstore_common_proto protoreflect.FileDescriptor
Types ¶
type DistinguishedName ¶
type DistinguishedName struct {
Organization string `protobuf:"bytes,1,opt,name=organization,proto3" json:"organization,omitempty"`
CommonName string `protobuf:"bytes,2,opt,name=common_name,json=commonName,proto3" json:"common_name,omitempty"`
// contains filtered or unexported fields
}
func (*DistinguishedName) Descriptor ¶
func (*DistinguishedName) Descriptor() ([]byte, []int)
Deprecated: Use DistinguishedName.ProtoReflect.Descriptor instead.
func (*DistinguishedName) GetCommonName ¶
func (x *DistinguishedName) GetCommonName() string
func (*DistinguishedName) GetOrganization ¶
func (x *DistinguishedName) GetOrganization() string
func (*DistinguishedName) ProtoMessage ¶
func (*DistinguishedName) ProtoMessage()
func (*DistinguishedName) ProtoReflect ¶
func (x *DistinguishedName) ProtoReflect() protoreflect.Message
func (*DistinguishedName) Reset ¶
func (x *DistinguishedName) Reset()
func (*DistinguishedName) String ¶
func (x *DistinguishedName) String() string
type HashAlgorithm ¶
type HashAlgorithm int32
Only a subset of the secure hash standard algorithms are supported. See <https://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.180-4.pdf> for more details. UNSPECIFIED SHOULD not be used, primary reason for inclusion is to force any proto JSON serialization to emit the used hash algorithm, as default option is to *omit* the default value of an enum (which is the first value, represented by '0'.
const ( HashAlgorithm_HASH_ALGORITHM_UNSPECIFIED HashAlgorithm = 0 HashAlgorithm_SHA2_256 HashAlgorithm = 1 HashAlgorithm_SHA2_384 HashAlgorithm = 2 HashAlgorithm_SHA2_512 HashAlgorithm = 3 HashAlgorithm_SHA3_256 HashAlgorithm = 4 HashAlgorithm_SHA3_384 HashAlgorithm = 5 )
func (HashAlgorithm) Descriptor ¶
func (HashAlgorithm) Descriptor() protoreflect.EnumDescriptor
func (HashAlgorithm) Enum ¶
func (x HashAlgorithm) Enum() *HashAlgorithm
func (HashAlgorithm) EnumDescriptor ¶
func (HashAlgorithm) EnumDescriptor() ([]byte, []int)
Deprecated: Use HashAlgorithm.Descriptor instead.
func (HashAlgorithm) Number ¶
func (x HashAlgorithm) Number() protoreflect.EnumNumber
func (HashAlgorithm) String ¶
func (x HashAlgorithm) String() string
func (HashAlgorithm) Type ¶
func (HashAlgorithm) Type() protoreflect.EnumType
type HashOutput ¶
type HashOutput struct {
Algorithm HashAlgorithm `protobuf:"varint,1,opt,name=algorithm,proto3,enum=dev.sigstore.common.v1.HashAlgorithm" json:"algorithm,omitempty"`
// This is the raw octets of the message digest as computed by
// the hash algorithm.
Digest []byte `protobuf:"bytes,2,opt,name=digest,proto3" json:"digest,omitempty"`
// contains filtered or unexported fields
}
HashOutput captures a digest of a 'message' (generic octet sequence) and the corresponding hash algorithm used.
func (*HashOutput) Descriptor ¶
func (*HashOutput) Descriptor() ([]byte, []int)
Deprecated: Use HashOutput.ProtoReflect.Descriptor instead.
func (*HashOutput) GetAlgorithm ¶
func (x *HashOutput) GetAlgorithm() HashAlgorithm
func (*HashOutput) GetDigest ¶
func (x *HashOutput) GetDigest() []byte
func (*HashOutput) ProtoMessage ¶
func (*HashOutput) ProtoMessage()
func (*HashOutput) ProtoReflect ¶
func (x *HashOutput) ProtoReflect() protoreflect.Message
func (*HashOutput) Reset ¶
func (x *HashOutput) Reset()
func (*HashOutput) String ¶
func (x *HashOutput) String() string
type LogId ¶
type LogId struct {
// The unique identity of the log, represented by its public key.
KeyId []byte `protobuf:"bytes,1,opt,name=key_id,json=keyId,proto3" json:"key_id,omitempty"`
// contains filtered or unexported fields
}
LogId captures the identity of a transparency log.
func (*LogId) Descriptor ¶
Deprecated: Use LogId.ProtoReflect.Descriptor instead.
func (*LogId) GetKeyId ¶
func (*LogId) ProtoMessage ¶
func (*LogId) ProtoMessage()
func (*LogId) ProtoReflect ¶
func (x *LogId) ProtoReflect() protoreflect.Message
func (*LogId) Reset ¶
func (x *LogId) Reset()
func (*LogId) String ¶
type MessageSignature ¶
type MessageSignature struct {
// Message digest can be used to identify the artifact.
// Clients MUST NOT attempt to use this digest to verify the associated
// signature; it is intended solely for identification.
MessageDigest *HashOutput `protobuf:"bytes,1,opt,name=message_digest,json=messageDigest,proto3" json:"message_digest,omitempty"`
// The raw bytes as returned from the signature algorithm.
// The signature algorithm (and so the format of the signature bytes)
// are determined by the contents of the 'verification_material',
// either a key-pair or a certificate. If using a certificate, the
// certificate contains the required information on the signature
// algorithm.
// When using a key pair, the algorithm MUST be part of the public
// key, which MUST be communicated out-of-band.
Signature []byte `protobuf:"bytes,2,opt,name=signature,proto3" json:"signature,omitempty"`
// contains filtered or unexported fields
}
MessageSignature stores the computed signature over a message.
func (*MessageSignature) Descriptor ¶
func (*MessageSignature) Descriptor() ([]byte, []int)
Deprecated: Use MessageSignature.ProtoReflect.Descriptor instead.
func (*MessageSignature) GetMessageDigest ¶
func (x *MessageSignature) GetMessageDigest() *HashOutput
func (*MessageSignature) GetSignature ¶
func (x *MessageSignature) GetSignature() []byte
func (*MessageSignature) ProtoMessage ¶
func (*MessageSignature) ProtoMessage()
func (*MessageSignature) ProtoReflect ¶
func (x *MessageSignature) ProtoReflect() protoreflect.Message
func (*MessageSignature) Reset ¶
func (x *MessageSignature) Reset()
func (*MessageSignature) String ¶
func (x *MessageSignature) String() string
type ObjectIdentifier ¶
type ObjectIdentifier struct {
Id []int32 `protobuf:"varint,1,rep,packed,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
An ASN.1 OBJECT IDENTIFIER
func (*ObjectIdentifier) Descriptor ¶
func (*ObjectIdentifier) Descriptor() ([]byte, []int)
Deprecated: Use ObjectIdentifier.ProtoReflect.Descriptor instead.
func (*ObjectIdentifier) GetId ¶
func (x *ObjectIdentifier) GetId() []int32
func (*ObjectIdentifier) ProtoMessage ¶
func (*ObjectIdentifier) ProtoMessage()
func (*ObjectIdentifier) ProtoReflect ¶
func (x *ObjectIdentifier) ProtoReflect() protoreflect.Message
func (*ObjectIdentifier) Reset ¶
func (x *ObjectIdentifier) Reset()
func (*ObjectIdentifier) String ¶
func (x *ObjectIdentifier) String() string
type ObjectIdentifierValuePair ¶
type ObjectIdentifierValuePair struct {
Oid *ObjectIdentifier `protobuf:"bytes,1,opt,name=oid,proto3" json:"oid,omitempty"`
Value []byte `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
An OID and the corresponding (byte) value.
func (*ObjectIdentifierValuePair) Descriptor ¶
func (*ObjectIdentifierValuePair) Descriptor() ([]byte, []int)
Deprecated: Use ObjectIdentifierValuePair.ProtoReflect.Descriptor instead.
func (*ObjectIdentifierValuePair) GetOid ¶
func (x *ObjectIdentifierValuePair) GetOid() *ObjectIdentifier
func (*ObjectIdentifierValuePair) GetValue ¶
func (x *ObjectIdentifierValuePair) GetValue() []byte
func (*ObjectIdentifierValuePair) ProtoMessage ¶
func (*ObjectIdentifierValuePair) ProtoMessage()
func (*ObjectIdentifierValuePair) ProtoReflect ¶
func (x *ObjectIdentifierValuePair) ProtoReflect() protoreflect.Message
func (*ObjectIdentifierValuePair) Reset ¶
func (x *ObjectIdentifierValuePair) Reset()
func (*ObjectIdentifierValuePair) String ¶
func (x *ObjectIdentifierValuePair) String() string
type PublicKey ¶
type PublicKey struct {
// DER-encoded public key, encoding method is specified by the
// key_details attribute.
RawBytes []byte `protobuf:"bytes,1,opt,name=raw_bytes,json=rawBytes,proto3,oneof" json:"raw_bytes,omitempty"`
// Key encoding and signature algorithm to use for this key.
KeyDetails PublicKeyDetails `protobuf:"varint,2,opt,name=key_details,json=keyDetails,proto3,enum=dev.sigstore.common.v1.PublicKeyDetails" json:"key_details,omitempty"`
// Optional validity period for this key, *inclusive* of the endpoints.
ValidFor *TimeRange `protobuf:"bytes,3,opt,name=valid_for,json=validFor,proto3,oneof" json:"valid_for,omitempty"`
// contains filtered or unexported fields
}
func (*PublicKey) Descriptor ¶
Deprecated: Use PublicKey.ProtoReflect.Descriptor instead.
func (*PublicKey) GetKeyDetails ¶
func (x *PublicKey) GetKeyDetails() PublicKeyDetails
func (*PublicKey) GetRawBytes ¶
func (*PublicKey) GetValidFor ¶
func (*PublicKey) ProtoMessage ¶
func (*PublicKey) ProtoMessage()
func (*PublicKey) ProtoReflect ¶
func (x *PublicKey) ProtoReflect() protoreflect.Message
func (*PublicKey) Reset ¶
func (x *PublicKey) Reset()
func (*PublicKey) String ¶
type PublicKeyDetails ¶
type PublicKeyDetails int32
Details of a specific public key, capturing the the key encoding method, and signature algorithm.
PublicKeyDetails captures the public key/hash algorithm combinations recommended in the Sigstore ecosystem.
This is modelled as a linear set as we want to provide a small number of opinionated options instead of allowing every possible permutation.
Any changes to this enum MUST be reflected in the algorithm registry.
See: <https://github.com/sigstore/architecture-docs/blob/main/algorithm-registry.md>
To avoid the possibility of contradicting formats such as PKCS1 with ED25519 the valid permutations are listed as a linear set instead of a cartesian set (i.e one combined variable instead of two, one for encoding and one for the signature algorithm).
const ( PublicKeyDetails_PUBLIC_KEY_DETAILS_UNSPECIFIED PublicKeyDetails = 0 // RSA // // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKCS1_RSA_PKCS1V5 PublicKeyDetails = 1 // See RFC8017 // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKCS1_RSA_PSS PublicKeyDetails = 2 // See RFC8017 // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKIX_RSA_PKCS1V5 PublicKeyDetails = 3 // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKIX_RSA_PSS PublicKeyDetails = 4 // RSA public key in PKIX format, PKCS#1v1.5 signature PublicKeyDetails_PKIX_RSA_PKCS1V15_2048_SHA256 PublicKeyDetails = 9 PublicKeyDetails_PKIX_RSA_PKCS1V15_3072_SHA256 PublicKeyDetails = 10 PublicKeyDetails_PKIX_RSA_PKCS1V15_4096_SHA256 PublicKeyDetails = 11 // RSA public key in PKIX format, RSASSA-PSS signature PublicKeyDetails_PKIX_RSA_PSS_2048_SHA256 PublicKeyDetails = 16 // See RFC4055 PublicKeyDetails_PKIX_RSA_PSS_3072_SHA256 PublicKeyDetails = 17 PublicKeyDetails_PKIX_RSA_PSS_4096_SHA256 PublicKeyDetails = 18 // ECDSA // // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKIX_ECDSA_P256_HMAC_SHA_256 PublicKeyDetails = 6 // See RFC6979 PublicKeyDetails_PKIX_ECDSA_P256_SHA_256 PublicKeyDetails = 5 // See NIST FIPS 186-4 PublicKeyDetails_PKIX_ECDSA_P384_SHA_384 PublicKeyDetails = 12 PublicKeyDetails_PKIX_ECDSA_P521_SHA_512 PublicKeyDetails = 13 // Ed 25519 PublicKeyDetails_PKIX_ED25519 PublicKeyDetails = 7 // See RFC8032 PublicKeyDetails_PKIX_ED25519_PH PublicKeyDetails = 8 // These algorithms are deprecated and should not be used, but they // were/are being used by most Sigstore clients implementations. // // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKIX_ECDSA_P384_SHA_256 PublicKeyDetails = 19 // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_PKIX_ECDSA_P521_SHA_256 PublicKeyDetails = 20 // LMS and LM-OTS // // These algorithms are deprecated and should not be used. // Keys and signatures MAY be used by private Sigstore // deployments, but will not be supported by the public // good instance. // // USER WARNING: LMS and LM-OTS are both stateful signature schemes. // Using them correctly requires discretion and careful consideration // to ensure that individual secret keys are not used more than once. // In addition, LM-OTS is a single-use scheme, meaning that it // MUST NOT be used for more than one signature per LM-OTS key. // If you cannot maintain these invariants, you MUST NOT use these // schemes. // // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_LMS_SHA256 PublicKeyDetails = 14 // Deprecated: Marked as deprecated in sigstore_common.proto. PublicKeyDetails_LMOTS_SHA256 PublicKeyDetails = 15 // ML-DSA // // These ML_DSA_65 and ML-DSA_87 algorithms are the pure variants that // take data to sign rather than the prehash variants (HashML-DSA), which // take digests. While considered quantum-resistant, their usage // involves tradeoffs in that signatures and keys are much larger, and // this makes deployments more costly. // // USER WARNING: ML_DSA_65 and ML_DSA_87 are experimental algorithms. // In the future they MAY be used by private Sigstore deployments, but // they are not yet fully functional. This warning will be removed when // these algorithms are widely supported by Sigstore clients and servers, // but care should still be taken for production environments. PublicKeyDetails_ML_DSA_65 PublicKeyDetails = 21 // See NIST FIPS 204 PublicKeyDetails_ML_DSA_87 PublicKeyDetails = 22 )
func (PublicKeyDetails) Descriptor ¶
func (PublicKeyDetails) Descriptor() protoreflect.EnumDescriptor
func (PublicKeyDetails) Enum ¶
func (x PublicKeyDetails) Enum() *PublicKeyDetails
func (PublicKeyDetails) EnumDescriptor ¶
func (PublicKeyDetails) EnumDescriptor() ([]byte, []int)
Deprecated: Use PublicKeyDetails.Descriptor instead.
func (PublicKeyDetails) Number ¶
func (x PublicKeyDetails) Number() protoreflect.EnumNumber
func (PublicKeyDetails) String ¶
func (x PublicKeyDetails) String() string
func (PublicKeyDetails) Type ¶
func (PublicKeyDetails) Type() protoreflect.EnumType
type PublicKeyIdentifier ¶
type PublicKeyIdentifier struct {
// Optional unauthenticated hint on which key to use.
// The format of the hint must be agreed upon out of band by the
// signer and the verifiers, and so is not subject to this
// specification.
// Example use-case is to specify the public key to use, from a
// trusted key-ring.
// Implementors are RECOMMENDED to derive the value from the public
// key as described in RFC 6962.
// See: <https://www.rfc-editor.org/rfc/rfc6962#section-3.2>
Hint string `protobuf:"bytes,1,opt,name=hint,proto3" json:"hint,omitempty"`
// contains filtered or unexported fields
}
PublicKeyIdentifier can be used to identify an (out of band) delivered key, to verify a signature.
func (*PublicKeyIdentifier) Descriptor ¶
func (*PublicKeyIdentifier) Descriptor() ([]byte, []int)
Deprecated: Use PublicKeyIdentifier.ProtoReflect.Descriptor instead.
func (*PublicKeyIdentifier) GetHint ¶
func (x *PublicKeyIdentifier) GetHint() string
func (*PublicKeyIdentifier) ProtoMessage ¶
func (*PublicKeyIdentifier) ProtoMessage()
func (*PublicKeyIdentifier) ProtoReflect ¶
func (x *PublicKeyIdentifier) ProtoReflect() protoreflect.Message
func (*PublicKeyIdentifier) Reset ¶
func (x *PublicKeyIdentifier) Reset()
func (*PublicKeyIdentifier) String ¶
func (x *PublicKeyIdentifier) String() string
type RFC3161SignedTimestamp ¶
type RFC3161SignedTimestamp struct {
// Signed timestamp is the DER encoded TimeStampResponse.
// See https://www.rfc-editor.org/rfc/rfc3161.html#section-2.4.2
SignedTimestamp []byte `protobuf:"bytes,1,opt,name=signed_timestamp,json=signedTimestamp,proto3" json:"signed_timestamp,omitempty"`
// contains filtered or unexported fields
}
This message holds a RFC 3161 timestamp.
func (*RFC3161SignedTimestamp) Descriptor ¶
func (*RFC3161SignedTimestamp) Descriptor() ([]byte, []int)
Deprecated: Use RFC3161SignedTimestamp.ProtoReflect.Descriptor instead.
func (*RFC3161SignedTimestamp) GetSignedTimestamp ¶
func (x *RFC3161SignedTimestamp) GetSignedTimestamp() []byte
func (*RFC3161SignedTimestamp) ProtoMessage ¶
func (*RFC3161SignedTimestamp) ProtoMessage()
func (*RFC3161SignedTimestamp) ProtoReflect ¶
func (x *RFC3161SignedTimestamp) ProtoReflect() protoreflect.Message
func (*RFC3161SignedTimestamp) Reset ¶
func (x *RFC3161SignedTimestamp) Reset()
func (*RFC3161SignedTimestamp) String ¶
func (x *RFC3161SignedTimestamp) String() string
type SubjectAlternativeName ¶
type SubjectAlternativeName struct {
Type SubjectAlternativeNameType `protobuf:"varint,1,opt,name=type,proto3,enum=dev.sigstore.common.v1.SubjectAlternativeNameType" json:"type,omitempty"`
// Types that are valid to be assigned to Identity:
//
// *SubjectAlternativeName_Regexp
// *SubjectAlternativeName_Value
Identity isSubjectAlternativeName_Identity `protobuf_oneof:"identity"`
// contains filtered or unexported fields
}
func (*SubjectAlternativeName) Descriptor ¶
func (*SubjectAlternativeName) Descriptor() ([]byte, []int)
Deprecated: Use SubjectAlternativeName.ProtoReflect.Descriptor instead.
func (*SubjectAlternativeName) GetIdentity ¶
func (x *SubjectAlternativeName) GetIdentity() isSubjectAlternativeName_Identity
func (*SubjectAlternativeName) GetRegexp ¶
func (x *SubjectAlternativeName) GetRegexp() string
func (*SubjectAlternativeName) GetType ¶
func (x *SubjectAlternativeName) GetType() SubjectAlternativeNameType
func (*SubjectAlternativeName) GetValue ¶
func (x *SubjectAlternativeName) GetValue() string
func (*SubjectAlternativeName) ProtoMessage ¶
func (*SubjectAlternativeName) ProtoMessage()
func (*SubjectAlternativeName) ProtoReflect ¶
func (x *SubjectAlternativeName) ProtoReflect() protoreflect.Message
func (*SubjectAlternativeName) Reset ¶
func (x *SubjectAlternativeName) Reset()
func (*SubjectAlternativeName) String ¶
func (x *SubjectAlternativeName) String() string
type SubjectAlternativeNameType ¶
type SubjectAlternativeNameType int32
const ( SubjectAlternativeNameType_SUBJECT_ALTERNATIVE_NAME_TYPE_UNSPECIFIED SubjectAlternativeNameType = 0 SubjectAlternativeNameType_EMAIL SubjectAlternativeNameType = 1 SubjectAlternativeNameType_URI SubjectAlternativeNameType = 2 // OID 1.3.6.1.4.1.57264.1.7 // See https://github.com/sigstore/fulcio/blob/main/docs/oid-info.md#1361415726417--othername-san // for more details. SubjectAlternativeNameType_OTHER_NAME SubjectAlternativeNameType = 3 )
func (SubjectAlternativeNameType) Descriptor ¶
func (SubjectAlternativeNameType) Descriptor() protoreflect.EnumDescriptor
func (SubjectAlternativeNameType) Enum ¶
func (x SubjectAlternativeNameType) Enum() *SubjectAlternativeNameType
func (SubjectAlternativeNameType) EnumDescriptor ¶
func (SubjectAlternativeNameType) EnumDescriptor() ([]byte, []int)
Deprecated: Use SubjectAlternativeNameType.Descriptor instead.
func (SubjectAlternativeNameType) Number ¶
func (x SubjectAlternativeNameType) Number() protoreflect.EnumNumber
func (SubjectAlternativeNameType) String ¶
func (x SubjectAlternativeNameType) String() string
func (SubjectAlternativeNameType) Type ¶
func (SubjectAlternativeNameType) Type() protoreflect.EnumType
type SubjectAlternativeName_Regexp ¶
type SubjectAlternativeName_Regexp struct {
// A regular expression describing the expected value for
// the SAN.
Regexp string `protobuf:"bytes,2,opt,name=regexp,proto3,oneof"`
}
type SubjectAlternativeName_Value ¶
type SubjectAlternativeName_Value struct {
// The exact value to match against.
Value string `protobuf:"bytes,3,opt,name=value,proto3,oneof"`
}
type TimeRange ¶
type TimeRange struct {
Start *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=start,proto3" json:"start,omitempty"`
End *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end,proto3,oneof" json:"end,omitempty"`
// contains filtered or unexported fields
}
The time range is closed and includes both the start and end times, (i.e., [start, end]). End is optional to be able to capture a period that has started but has no known end.
func (*TimeRange) Descriptor ¶
Deprecated: Use TimeRange.ProtoReflect.Descriptor instead.
func (*TimeRange) GetEnd ¶
func (x *TimeRange) GetEnd() *timestamppb.Timestamp
func (*TimeRange) GetStart ¶
func (x *TimeRange) GetStart() *timestamppb.Timestamp
func (*TimeRange) ProtoMessage ¶
func (*TimeRange) ProtoMessage()
func (*TimeRange) ProtoReflect ¶
func (x *TimeRange) ProtoReflect() protoreflect.Message
func (*TimeRange) Reset ¶
func (x *TimeRange) Reset()
func (*TimeRange) String ¶
type X509Certificate ¶
type X509Certificate struct {
// DER-encoded X.509 certificate.
RawBytes []byte `protobuf:"bytes,1,opt,name=raw_bytes,json=rawBytes,proto3" json:"raw_bytes,omitempty"`
// contains filtered or unexported fields
}
func (*X509Certificate) Descriptor ¶
func (*X509Certificate) Descriptor() ([]byte, []int)
Deprecated: Use X509Certificate.ProtoReflect.Descriptor instead.
func (*X509Certificate) GetRawBytes ¶
func (x *X509Certificate) GetRawBytes() []byte
func (*X509Certificate) ProtoMessage ¶
func (*X509Certificate) ProtoMessage()
func (*X509Certificate) ProtoReflect ¶
func (x *X509Certificate) ProtoReflect() protoreflect.Message
func (*X509Certificate) Reset ¶
func (x *X509Certificate) Reset()
func (*X509Certificate) String ¶
func (x *X509Certificate) String() string
type X509CertificateChain ¶
type X509CertificateChain struct {
// One or more DER-encoded certificates.
//
// In some contexts (such as `VerificationMaterial.x509_certificate_chain`), this sequence
// has an imposed order. Unless explicitly specified, there is otherwise no
// guaranteed order.
Certificates []*X509Certificate `protobuf:"bytes,1,rep,name=certificates,proto3" json:"certificates,omitempty"`
// contains filtered or unexported fields
}
A collection of X.509 certificates.
This "chain" can be used in multiple contexts, such as providing a root CA certificate within a TUF root of trust or multiple untrusted certificates for the purpose of chain building.
func (*X509CertificateChain) Descriptor ¶
func (*X509CertificateChain) Descriptor() ([]byte, []int)
Deprecated: Use X509CertificateChain.ProtoReflect.Descriptor instead.
func (*X509CertificateChain) GetCertificates ¶
func (x *X509CertificateChain) GetCertificates() []*X509Certificate
func (*X509CertificateChain) ProtoMessage ¶
func (*X509CertificateChain) ProtoMessage()
func (*X509CertificateChain) ProtoReflect ¶
func (x *X509CertificateChain) ProtoReflect() protoreflect.Message
func (*X509CertificateChain) Reset ¶
func (x *X509CertificateChain) Reset()
func (*X509CertificateChain) String ¶
func (x *X509CertificateChain) String() string
Source Files ¶
- Version
- v0.4.3 (latest)
- Published
- Jun 9, 2025
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 10 months ago –
Tools for package owners.