package v2

import "github.com/sigstore/protobuf-specs/gen/pb-go/rekor/v2"

Index

Variables

var File_rekor_v2_dsse_proto protoreflect.FileDescriptor
var File_rekor_v2_entry_proto protoreflect.FileDescriptor
var File_rekor_v2_hashedrekord_proto protoreflect.FileDescriptor
var File_rekor_v2_verifier_proto protoreflect.FileDescriptor

Types

type CreateEntryRequest

type CreateEntryRequest struct {

	// Types that are valid to be assigned to Spec:
	//
	//	*CreateEntryRequest_HashedRekordRequestV002
	//	*CreateEntryRequest_DsseRequestV002
	Spec isCreateEntryRequest_Spec `protobuf_oneof:"spec"`
	// contains filtered or unexported fields
}

Create a new HashedRekord or DSSE

func (*CreateEntryRequest) Descriptor

func (*CreateEntryRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateEntryRequest.ProtoReflect.Descriptor instead.

func (*CreateEntryRequest) GetDsseRequestV002

func (x *CreateEntryRequest) GetDsseRequestV002() *DSSERequestV002

func (*CreateEntryRequest) GetHashedRekordRequestV002

func (x *CreateEntryRequest) GetHashedRekordRequestV002() *HashedRekordRequestV002

func (*CreateEntryRequest) GetSpec

func (x *CreateEntryRequest) GetSpec() isCreateEntryRequest_Spec

func (*CreateEntryRequest) ProtoMessage

func (*CreateEntryRequest) ProtoMessage()

func (*CreateEntryRequest) ProtoReflect

func (x *CreateEntryRequest) ProtoReflect() protoreflect.Message

func (*CreateEntryRequest) Reset

func (x *CreateEntryRequest) Reset()

func (*CreateEntryRequest) String

func (x *CreateEntryRequest) String() string

type CreateEntryRequest_DsseRequestV002

type CreateEntryRequest_DsseRequestV002 struct {
	DsseRequestV002 *DSSERequestV002 `protobuf:"bytes,2,opt,name=dsse_request_v002,json=dsseRequestV002,proto3,oneof"`
}

type CreateEntryRequest_HashedRekordRequestV002

type CreateEntryRequest_HashedRekordRequestV002 struct {
	HashedRekordRequestV002 *HashedRekordRequestV002 `protobuf:"bytes,1,opt,name=hashed_rekord_request_v002,json=hashedRekordRequestV002,proto3,oneof"`
}

type DSSELogEntryV002

type DSSELogEntryV002 struct {

	// The hash of the DSSE payload
	PayloadHash *v1.HashOutput `protobuf:"bytes,1,opt,name=payloadHash,proto3" json:"payloadHash,omitempty"`
	// Signatures and their associated verification material used to verify the payload
	Signatures []*Signature `protobuf:"bytes,2,rep,name=signatures,proto3" json:"signatures,omitempty"`
	// contains filtered or unexported fields
}

func (*DSSELogEntryV002) Descriptor

func (*DSSELogEntryV002) Descriptor() ([]byte, []int)

Deprecated: Use DSSELogEntryV002.ProtoReflect.Descriptor instead.

func (*DSSELogEntryV002) GetPayloadHash

func (x *DSSELogEntryV002) GetPayloadHash() *v1.HashOutput

func (*DSSELogEntryV002) GetSignatures

func (x *DSSELogEntryV002) GetSignatures() []*Signature

func (*DSSELogEntryV002) ProtoMessage

func (*DSSELogEntryV002) ProtoMessage()

func (*DSSELogEntryV002) ProtoReflect

func (x *DSSELogEntryV002) ProtoReflect() protoreflect.Message

func (*DSSELogEntryV002) Reset

func (x *DSSELogEntryV002) Reset()

func (*DSSELogEntryV002) String

func (x *DSSELogEntryV002) String() string

type DSSERequestV002

type DSSERequestV002 struct {

	// A DSSE envelope
	Envelope *dsse.Envelope `protobuf:"bytes,1,opt,name=envelope,proto3" json:"envelope,omitempty"`
	// All necessary verification material to verify all signatures embedded in the envelope
	Verifiers []*Verifier `protobuf:"bytes,2,rep,name=verifiers,proto3" json:"verifiers,omitempty"`
	// contains filtered or unexported fields
}

A request to add a DSSE v0.0.2 entry to the log

func (*DSSERequestV002) Descriptor

func (*DSSERequestV002) Descriptor() ([]byte, []int)

Deprecated: Use DSSERequestV002.ProtoReflect.Descriptor instead.

func (*DSSERequestV002) GetEnvelope

func (x *DSSERequestV002) GetEnvelope() *dsse.Envelope

func (*DSSERequestV002) GetVerifiers

func (x *DSSERequestV002) GetVerifiers() []*Verifier

func (*DSSERequestV002) ProtoMessage

func (*DSSERequestV002) ProtoMessage()

func (*DSSERequestV002) ProtoReflect

func (x *DSSERequestV002) ProtoReflect() protoreflect.Message

func (*DSSERequestV002) Reset

func (x *DSSERequestV002) Reset()

func (*DSSERequestV002) String

func (x *DSSERequestV002) String() string

type Entry

type Entry struct {
	Kind       string `protobuf:"bytes,1,opt,name=kind,proto3" json:"kind,omitempty"`
	ApiVersion string `protobuf:"bytes,2,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
	Spec       *Spec  `protobuf:"bytes,3,opt,name=spec,proto3" json:"spec,omitempty"`
	// contains filtered or unexported fields
}

Entry is the message that is canonicalized and uploaded to the log. This format is meant to be compliant with Rekor v1 entries in that the `apiVersion` and `kind` can be parsed before parsing the spec. Clients are expected to understand and handle the differences in the contents of `spec` between Rekor v1 (a polymorphic OpenAPI defintion) and Rekor v2 (a typed proto defintion).

func (*Entry) Descriptor

func (*Entry) Descriptor() ([]byte, []int)

Deprecated: Use Entry.ProtoReflect.Descriptor instead.

func (*Entry) GetApiVersion

func (x *Entry) GetApiVersion() string

func (*Entry) GetKind

func (x *Entry) GetKind() string

func (*Entry) GetSpec

func (x *Entry) GetSpec() *Spec

func (*Entry) ProtoMessage

func (*Entry) ProtoMessage()

func (*Entry) ProtoReflect

func (x *Entry) ProtoReflect() protoreflect.Message

func (*Entry) Reset

func (x *Entry) Reset()

func (*Entry) String

func (x *Entry) String() string

type HashedRekordLogEntryV002

type HashedRekordLogEntryV002 struct {

	// The hashed data
	Data *v1.HashOutput `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// A single signature over the hashed data with the verifier needed to validate it
	Signature *Signature `protobuf:"bytes,2,opt,name=signature,proto3" json:"signature,omitempty"`
	// contains filtered or unexported fields
}

func (*HashedRekordLogEntryV002) Descriptor

func (*HashedRekordLogEntryV002) Descriptor() ([]byte, []int)

Deprecated: Use HashedRekordLogEntryV002.ProtoReflect.Descriptor instead.

func (*HashedRekordLogEntryV002) GetData

func (x *HashedRekordLogEntryV002) GetData() *v1.HashOutput

func (*HashedRekordLogEntryV002) GetSignature

func (x *HashedRekordLogEntryV002) GetSignature() *Signature

func (*HashedRekordLogEntryV002) ProtoMessage

func (*HashedRekordLogEntryV002) ProtoMessage()

func (*HashedRekordLogEntryV002) ProtoReflect

func (x *HashedRekordLogEntryV002) ProtoReflect() protoreflect.Message

func (*HashedRekordLogEntryV002) Reset

func (x *HashedRekordLogEntryV002) Reset()

func (*HashedRekordLogEntryV002) String

func (x *HashedRekordLogEntryV002) String() string

type HashedRekordRequestV002

type HashedRekordRequestV002 struct {

	// The hashed data
	Digest []byte `protobuf:"bytes,1,opt,name=digest,proto3" json:"digest,omitempty"`
	// A single signature over the hashed data with the verifier needed to validate it
	Signature *Signature `protobuf:"bytes,2,opt,name=signature,proto3" json:"signature,omitempty"`
	// contains filtered or unexported fields
}

A request to add a hashedrekord v0.0.2 to the log

func (*HashedRekordRequestV002) Descriptor

func (*HashedRekordRequestV002) Descriptor() ([]byte, []int)

Deprecated: Use HashedRekordRequestV002.ProtoReflect.Descriptor instead.

func (*HashedRekordRequestV002) GetDigest

func (x *HashedRekordRequestV002) GetDigest() []byte

func (*HashedRekordRequestV002) GetSignature

func (x *HashedRekordRequestV002) GetSignature() *Signature

func (*HashedRekordRequestV002) ProtoMessage

func (*HashedRekordRequestV002) ProtoMessage()

func (*HashedRekordRequestV002) ProtoReflect

func (x *HashedRekordRequestV002) ProtoReflect() protoreflect.Message

func (*HashedRekordRequestV002) Reset

func (x *HashedRekordRequestV002) Reset()

func (*HashedRekordRequestV002) String

func (x *HashedRekordRequestV002) String() string

type PublicKey

type PublicKey struct {

	// DER-encoded public key
	RawBytes []byte `protobuf:"bytes,1,opt,name=raw_bytes,json=rawBytes,proto3" json:"raw_bytes,omitempty"`
	// contains filtered or unexported fields
}

PublicKey contains an encoded public key

func (*PublicKey) Descriptor

func (*PublicKey) Descriptor() ([]byte, []int)

Deprecated: Use PublicKey.ProtoReflect.Descriptor instead.

func (*PublicKey) GetRawBytes

func (x *PublicKey) GetRawBytes() []byte

func (*PublicKey) ProtoMessage

func (*PublicKey) ProtoMessage()

func (*PublicKey) ProtoReflect

func (x *PublicKey) ProtoReflect() protoreflect.Message

func (*PublicKey) Reset

func (x *PublicKey) Reset()

func (*PublicKey) String

func (x *PublicKey) String() string

type Signature

type Signature struct {
	Content  []byte    `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
	Verifier *Verifier `protobuf:"bytes,2,opt,name=verifier,proto3" json:"verifier,omitempty"`
	// contains filtered or unexported fields
}

A signature and an associated verifier

func (*Signature) Descriptor

func (*Signature) Descriptor() ([]byte, []int)

Deprecated: Use Signature.ProtoReflect.Descriptor instead.

func (*Signature) GetContent

func (x *Signature) GetContent() []byte

func (*Signature) GetVerifier

func (x *Signature) GetVerifier() *Verifier

func (*Signature) ProtoMessage

func (*Signature) ProtoMessage()

func (*Signature) ProtoReflect

func (x *Signature) ProtoReflect() protoreflect.Message

func (*Signature) Reset

func (x *Signature) Reset()

func (*Signature) String

func (x *Signature) String() string

type Spec

type Spec struct {

	// Types that are valid to be assigned to Spec:
	//
	//	*Spec_HashedRekordV002
	//	*Spec_DsseV002
	Spec isSpec_Spec `protobuf_oneof:"spec"`
	// contains filtered or unexported fields
}

Spec contains one of the Rekor entry types.

func (*Spec) Descriptor

func (*Spec) Descriptor() ([]byte, []int)

Deprecated: Use Spec.ProtoReflect.Descriptor instead.

func (*Spec) GetDsseV002

func (x *Spec) GetDsseV002() *DSSELogEntryV002

func (*Spec) GetHashedRekordV002

func (x *Spec) GetHashedRekordV002() *HashedRekordLogEntryV002

func (*Spec) GetSpec

func (x *Spec) GetSpec() isSpec_Spec

func (*Spec) ProtoMessage

func (*Spec) ProtoMessage()

func (*Spec) ProtoReflect

func (x *Spec) ProtoReflect() protoreflect.Message

func (*Spec) Reset

func (x *Spec) Reset()

func (*Spec) String

func (x *Spec) String() string

type Spec_DsseV002

type Spec_DsseV002 struct {
	DsseV002 *DSSELogEntryV002 `protobuf:"bytes,2,opt,name=dsse_v002,json=dsseV002,proto3,oneof"`
}

type Spec_HashedRekordV002

type Spec_HashedRekordV002 struct {
	HashedRekordV002 *HashedRekordLogEntryV002 `protobuf:"bytes,1,opt,name=hashed_rekord_v002,json=hashedRekordV002,proto3,oneof"`
}

type Verifier

type Verifier struct {

	// Types that are valid to be assigned to Verifier:
	//
	//	*Verifier_PublicKey
	//	*Verifier_X509Certificate
	Verifier isVerifier_Verifier `protobuf_oneof:"verifier"`
	// Key encoding and signature algorithm to use for this key
	KeyDetails v1.PublicKeyDetails `protobuf:"varint,3,opt,name=key_details,json=keyDetails,proto3,enum=dev.sigstore.common.v1.PublicKeyDetails" json:"key_details,omitempty"`
	// contains filtered or unexported fields
}

Either a public key or a X.509 cerificiate with an embedded public key

func (*Verifier) Descriptor

func (*Verifier) Descriptor() ([]byte, []int)

Deprecated: Use Verifier.ProtoReflect.Descriptor instead.

func (*Verifier) GetKeyDetails

func (x *Verifier) GetKeyDetails() v1.PublicKeyDetails

func (*Verifier) GetPublicKey

func (x *Verifier) GetPublicKey() *PublicKey

func (*Verifier) GetVerifier

func (x *Verifier) GetVerifier() isVerifier_Verifier

func (*Verifier) GetX509Certificate

func (x *Verifier) GetX509Certificate() *v1.X509Certificate

func (*Verifier) ProtoMessage

func (*Verifier) ProtoMessage()

func (*Verifier) ProtoReflect

func (x *Verifier) ProtoReflect() protoreflect.Message

func (*Verifier) Reset

func (x *Verifier) Reset()

func (*Verifier) String

func (x *Verifier) String() string

type Verifier_PublicKey

type Verifier_PublicKey struct {
	// DER-encoded public key. Encoding method is specified by the key_details attribute
	PublicKey *PublicKey `protobuf:"bytes,1,opt,name=public_key,json=publicKey,proto3,oneof"`
}

type Verifier_X509Certificate

type Verifier_X509Certificate struct {
	// DER-encoded certificate
	X509Certificate *v1.X509Certificate `protobuf:"bytes,2,opt,name=x509_certificate,json=x509Certificate,proto3,oneof"`
}

Source Files

dsse.pb.go entry.pb.go hashedrekord.pb.go verifier.pb.go

Version
v0.4.3 (latest)
Published
Jun 9, 2025
Platform
linux/amd64
Imports
8 packages
Last checked
10 months ago

Tools for package owners.